/**
 * @name checkAuthenticated
 * @description Check if user is authenticated (if auth'd, continue, else redirect to login)
 * @param {*} request Express request object
 * @param {*} response Express response object
 * @param {Function} next Express next function
 * @returns {void}
 */
export async function checkAuthenticated(request, response, next)
{
    try
    {
        if (request.isAuthenticated())
            return next();
        response.redirect(`/`);
    }
    catch
    {
        request.logout((error) =>
        {
            if (error)
                return response.status(500).json({ message: `Error logging out` });
            return response.redirect(`/`);
        });
    }
}

/**
 * @name checkNotAuthenticated
 * @description Check if user is not authenticated (if not auth'd, continue, else redirect to root) [Used to prevent logged in users from accessing login/register pages, etc.]
 * @param {*} request Express request object
 * @param {*} response Express response object
 * @param {Function} next Express next function
 * @returns {void}
 */
export function checkNotAuthenticated(request, response, next)
{
    if (!request.isAuthenticated())
        return next();
    return response.redirect(`/profile`); // Already logged in
}
