/* eslint-disable import/no-extraneous-dependencies */
import express from "express";
import { config } from "dotenv";
import passport from "passport";

import index from "./routes/index.js";
import notFound from "./routes/404.js";
import logout from "./routes/logout.js";
import profile from "./routes/profile.js";

config(); // Load environment variables from .env file

const router = new express.Router();

router.use(`/`, index);
router.use(`/logout`, logout);
router.use(`/profile`, profile);
router.get(`/error`, (request, response) => response.send(`Error getting data. We may be rate limited by Spotify (try again later).`));

// Social Logins
if (process.env.SPOTIFY_CLIENT_ID && process.env.SPOTIFY_CLIENT_SECRET)
{
    router.get(`/login/spotify`, passport.authenticate(`spotify`, {
        scope: [`user-top-read`],
    }));
    router.get(
        `/login/spotify/callback`,
        passport.authenticate(`spotify`, {
            failureRedirect: `/`,
        }),
        (request, response) =>
        {
            // take the callback code from the url and redirect to /profile?code=...
            response.redirect(`/profile`);
        }
    );
}

router.use(`/*`, notFound);

export default router;
